[PATCH] emacs: Prefer email address over User ID when showing valid signature

Subject: [PATCH] emacs: Prefer email address over User ID when showing valid signature

Date: Sat, 26 Jun 2021 13:41:44 -0300

To: Daniel Kahn Gillmor, Notmuch Mail

Cc:

From: David Bremner


From: Daniel Kahn Gillmor <dkg@fifthhorseman.net>

Most concrete verification steps are likely only taken on the e-mail
address in the first place, and e-mail addresses render more
intelligibly than arbitrary User IDs in the first place.

Signed-off-by: Daniel Kahn Gillmor <dkg@fifthhorseman.net>
Amended-by: db, apply dme restructuring suggestions.
---
 emacs/notmuch-crypto.el | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/emacs/notmuch-crypto.el b/emacs/notmuch-crypto.el
index db7cb75d..5edfe94c 100644
--- a/emacs/notmuch-crypto.el
+++ b/emacs/notmuch-crypto.el
@@ -119,14 +119,14 @@ mode."
     (cond
      ((string= status "good")
       (let ((fingerprint (concat "0x" (plist-get sigstatus :fingerprint)))
-	    (userid (plist-get sigstatus :userid)))
-	;; If userid is present it has full or greater validity.
-	(if userid
-	    (progn
-	      (setq label (concat "Good signature by: " userid))
-	      (setq face 'notmuch-crypto-signature-good))
-	  (setq label (concat "Good signature by key: " fingerprint))
-	  (setq face 'notmuch-crypto-signature-good-key))
+	    (email-or-userid (or (plist-get sigstatus :email)
+				  (plist-get sigstatus :userid))))
+	;; If email or userid are present, they have full or greater validity.
+	(setq label (concat "Good signature by key: " fingerprint))
+	(setq face 'notmuch-crypto-signature-good-key)
+	(when email-or-userid
+	  (setq label (concat "Good signature by: " email-or-user-id))
+	  (setq face 'notmuch-crypto-signature-good))
 	(setq button-action 'notmuch-crypto-sigstatus-good-callback)
 	(setq help-msg (concat "Click to list key ID 0x" fingerprint "."))))
      ((string= status "error")
-- 
2.30.2
_______________________________________________
notmuch mailing list -- notmuch@notmuchmail.org
To unsubscribe send an email to notmuch-leave@notmuchmail.org

Thread: